@@ -218,9 +218,9 @@ class Bugzilla(WebScraper):
     Class for access to Novell bugzilla.
     '''
     def __init__(self, user, password, base='https://bugzilla.novell.com',
-                 useragent=None, timeout=10):
+                 useragent=None):
         super(Bugzilla, self).__init__(
-            user, password, base, useragent, timeout
+            user, password, base, useragent
         )
 
     def check_login(self):
@@ -343,7 +343,7 @@ class Bugzilla(WebScraper):
             return None
         return result[0]
 
-    def get_bugs(self, ids, retry=True, permissive=False):
+    def get_bugs(self, ids, retry=True, permissive=False, store_errors=False):
         '''
         Returns Bug objects based on data received from bugzilla for each bug
         ID.
@@ -375,6 +375,8 @@ class Bugzilla(WebScraper):
                 try:
                     bugs.append(Bug(bug, self.anonymous))
                 except BugzillaError as exc:
+                    if store_errors:
+                        bugs.append(exc)
                     if permissive:
                         logger.error(exc)
                     else:
@@ -560,9 +562,9 @@ class APIBugzilla(Bugzilla):
     Wrapper class to use apibugzilla.novell.com.
     '''
     def __init__(self, user, password, base='https://apibugzilla.novell.com',
-                 useragent=None, timeout=10):
+                 useragent=None):
         super(APIBugzilla, self).__init__(
-            user, password, base, useragent, timeout
+            user, password, base, useragent
         )
         # Use normal Bugzilla for anonymous access
         if self.anonymous and 'novell.com' in base:
@@ -617,7 +619,6 @@ def get_django_bugzilla():
         settings.BUGZILLA_USERNAME,
         settings.BUGZILLA_PASSWORD,
         useragent=settings.EMAIL_SUBJECT_PREFIX.strip('[] '),
-        timeout=settings.BUGZILLA_TIMEOUT
     )
 
     # Check for anonymous access
